@@ -3,10 +3,10 @@
 #############################################################################
 ## 
 ##   Bash script to be sourced by the logtalk_tester script
-##   Last updated on October 29, 2018
+##   Last updated on December 3, 2018
 ## 
 ##   This file is part of Logtalk <https://logtalk.org/>  
-##   Copyright 1998-2018 Paulo Moura <pmoura@logtalk.org>
+##   Copyright 1998-2019 Paulo Moura <pmoura@logtalk.org>
 ##   
 ##   Licensed under the Apache License, Version 2.0 (the "License");
 ##   you may not use this file except in compliance with the License.
@@ -24,12 +24,15 @@
 
 
 while getopts "p:" option; do
-    case $option in
+	case $option in
 		p) backend="$OPTARG";;
-    esac
+	esac
 done
 
-if [ "$backend" == "swipl" ] ; then
+if [ "$backend" == "swi" ] ; then
+	source set_classpath_swi.sh
+	export CLASSPATH
+elif [ "$backend" == "swipack" ] ; then
 	source set_classpath_swi.sh
 	export CLASSPATH
 elif [ "$backend" == "yap" ] ; then
